@@ -21,7 +21,7 @@ static lookups generic[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
 	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -58,7 +58,6 @@ static lookups generic[] = {
 	{ "M1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*misc */
 	{ "M2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
 	{ "M3", "NOTES",        SIMPLE,  LEVEL_MAIN },
-	{ "  ", "TYPE|ARTICLE",           ALWAYS, LEVEL_MAIN }
 };
 
 static lookups article[] = {
@@ -69,7 +68,7 @@ static lookups article[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_HOST },
 	{ "PY", "PARTYEAR",     DATE,    LEVEL_MAIN },
 	{ "Y1", "PARTYEAR",     DATE,    LEVEL_MAIN },
-	{ "Y2", "PARTMONTHDAY", SIMPLE,  LEVEL_MAIN },
+	{ "Y2", "PARTMONTH", SIMPLE,  LEVEL_MAIN },
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_HOST },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -112,6 +111,59 @@ static lookups article[] = {
 	{ "  ", "GENRE|academic journal", ALWAYS, LEVEL_HOST }
 };
 
+/* magazine article */
+static lookups magarticle[] = {
+	{ "AU", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A1", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A2", "AUTHOR",       PERSON,  LEVEL_HOST },
+	{ "A3", "AUTHOR",       PERSON,  LEVEL_SERIES }, 
+	{ "ED", "EDITOR",       PERSON,  LEVEL_HOST },
+	{ "PY", "PARTYEAR",     DATE,    LEVEL_MAIN },
+	{ "Y1", "PARTYEAR",     DATE,    LEVEL_MAIN },
+	{ "Y2", "PARTMONTH", SIMPLE,  LEVEL_MAIN },
+	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_HOST },
+	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T2", "SHORTTITLE",   SIMPLE,  LEVEL_HOST },
+	{ "T3", "TITLE",        SIMPLE,  LEVEL_SERIES },
+	{ "JO", "TITLE",        SIMPLE,  LEVEL_HOST }, /* JOURNAL */
+	{ "JA", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "JF", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J1", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J2", "TITLE",        SIMPLE,  LEVEL_SERIES },
+	{ "VL", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "VO", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "IS", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "CP", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "SP", "PAGESTART",    SIMPLE,  LEVEL_MAIN },
+	{ "EP", "PAGEEND",      SIMPLE,  LEVEL_MAIN },
+	{ "AB", "ABSTRACT",     SIMPLE,  LEVEL_MAIN },
+	{ "N1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "N2", "ABSTRACT",     SIMPLE,  LEVEL_MAIN }, 
+	{ "KW", "KEYWORD",      SIMPLE,  LEVEL_MAIN },
+	{ "PB", "PUBLISHER",    SIMPLE,  LEVEL_HOST },
+	{ "CT", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "AD", "AUTHORADDRESS",SIMPLE,  LEVEL_MAIN },
+	{ "CY", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "RP", "REPRINTSTATUS",SIMPLE,  LEVEL_MAIN },
+	{ "UR", "URL",          SIMPLE,  LEVEL_MAIN },
+	{ "ID", "REFNUM",       SIMPLE,  LEVEL_MAIN },
+	{ "U1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U2", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U4", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U5", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M2", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "  ", "ISSUANCE|continuing",    ALWAYS, LEVEL_HOST },
+	{ "  ", "RESOURCE|text",          ALWAYS, LEVEL_MAIN },
+	{ "  ", "GENRE|periodical",       ALWAYS, LEVEL_HOST },
+	{ "  ", "GENRE|magazine",         ALWAYS, LEVEL_HOST }
+};
+
+
+
 static lookups newsarticle[] = {
 	{ "AU", "AUTHOR",       PERSON,  LEVEL_MAIN },
 	{ "A1", "AUTHOR",       PERSON,  LEVEL_MAIN },
@@ -120,7 +172,7 @@ static lookups newsarticle[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_HOST },
 	{ "PY", "PARTYEAR",     DATE,    LEVEL_MAIN },
 	{ "Y1", "PARTYEAR",     DATE,    LEVEL_MAIN },
-	{ "Y2", "PARTMONTHDAY", SIMPLE,  LEVEL_MAIN },
+	{ "Y2", "PARTMONTH", SIMPLE,  LEVEL_MAIN },
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_HOST },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -170,7 +222,7 @@ static lookups book[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
 	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_MAIN }, 
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN }, 
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -220,7 +272,7 @@ static lookups inbook[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_HOST },
 	{ "PY", "YEAR",         DATE,    LEVEL_HOST },
 	{ "Y1", "YEAR",         DATE,    LEVEL_HOST },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_HOST }, 
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_HOST }, 
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_HOST },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -265,7 +317,7 @@ static lookups conference[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_HOST },
 	{ "Y1", "YEAR",         DATE,    LEVEL_HOST },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_HOST }, 
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_HOST }, 
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -315,7 +367,7 @@ static lookups statute[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
 	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_MAIN }, 
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN }, 
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -365,7 +417,7 @@ static lookups hearing[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
 	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_MAIN }, 
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN }, 
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -414,7 +466,7 @@ static lookups cases[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
 	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_MAIN }, 
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN }, 
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -463,7 +515,7 @@ static lookups communication[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
 	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -512,7 +564,7 @@ static lookups thesis[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
 	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -562,7 +614,7 @@ static lookups report[] = {
 	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
 	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
 	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
-	{ "Y2", "MONTHDAY",     SIMPLE,  LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
 	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
 	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
 	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
@@ -604,12 +656,303 @@ static lookups report[] = {
 	{ "  ", "GENRE|report", ALWAYS,  LEVEL_MAIN }
 };
 
+static lookups abstract[] = {
+	{ "AU", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A1", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A2", "AUTHOR",       PERSON,  LEVEL_HOST },
+	{ "A3", "AUTHOR",       PERSON,  LEVEL_SERIES }, 
+	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
+	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
+	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
+	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T2", "SHORTTITLE",   SIMPLE,  LEVEL_HOST },
+	{ "T3", "TITLE",        SIMPLE,  LEVEL_SERIES },
+	{ "JO", "TITLE",        SIMPLE,  LEVEL_HOST }, /* JOURNAL */
+	{ "JA", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "JF", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J1", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J2", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "VL", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "VO", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "IS", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "CP", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "SP", "PAGESTART",    SIMPLE,  LEVEL_MAIN },
+	{ "EP", "PAGEEND",      SIMPLE,  LEVEL_MAIN },
+	{ "AB", "ABSTRACT",     SIMPLE,  LEVEL_MAIN },
+	{ "N1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "N2", "ABSTRACT",     SIMPLE,  LEVEL_MAIN }, 
+	{ "KW", "KEYWORD",      SIMPLE,  LEVEL_MAIN },
+	{ "PB", "PUBLISHER",    SIMPLE,  LEVEL_MAIN },
+	{ "BT", "TITLE",        SIMPLE,  LEVEL_HOST }, 
+	{ "CT", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "AD", "AUTHORADDRESS",SIMPLE,  LEVEL_MAIN },
+	{ "CY", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "RP", "REPRINTSTATUS",SIMPLE,  LEVEL_MAIN },
+	{ "UR", "URL",          SIMPLE,  LEVEL_MAIN },
+	{ "ID", "REFNUM",       SIMPLE,  LEVEL_MAIN },
+	{ "U1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*user defined */
+	{ "U2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "U3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U4", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U5", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*misc */
+	{ "M2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "M3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "  ", "GENRE|abstract or summary", ALWAYS,  LEVEL_MAIN }
+};
 
+static lookups program[] = {
+	{ "AU", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A1", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A2", "AUTHOR",       PERSON,  LEVEL_HOST },
+	{ "A3", "AUTHOR",       PERSON,  LEVEL_SERIES }, 
+	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
+	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
+	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
+	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T2", "SHORTTITLE",   SIMPLE,  LEVEL_HOST },
+	{ "T3", "TITLE",        SIMPLE,  LEVEL_SERIES },
+	{ "JO", "TITLE",        SIMPLE,  LEVEL_HOST }, /* JOURNAL */
+	{ "JA", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "JF", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J1", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J2", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "VL", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "VO", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "IS", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "CP", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "SP", "PAGESTART",    SIMPLE,  LEVEL_MAIN },
+	{ "EP", "PAGEEND",      SIMPLE,  LEVEL_MAIN },
+	{ "AB", "ABSTRACT",     SIMPLE,  LEVEL_MAIN },
+	{ "N1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "N2", "ABSTRACT",     SIMPLE,  LEVEL_MAIN }, 
+	{ "KW", "KEYWORD",      SIMPLE,  LEVEL_MAIN },
+	{ "PB", "PUBLISHER",    SIMPLE,  LEVEL_MAIN },
+	{ "BT", "TITLE",        SIMPLE,  LEVEL_HOST }, 
+	{ "CT", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "AD", "AUTHORADDRESS",SIMPLE,  LEVEL_MAIN },
+	{ "CY", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "RP", "REPRINTSTATUS",SIMPLE,  LEVEL_MAIN },
+	{ "UR", "URL",          SIMPLE,  LEVEL_MAIN },
+	{ "ID", "REFNUM",       SIMPLE,  LEVEL_MAIN },
+	{ "U1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*user defined */
+	{ "U2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "U3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U4", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U5", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*misc */
+	{ "M2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "M3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "  ", "RESOURCE|software, multimedia", ALWAYS, LEVEL_MAIN }
+};
+
+static lookups patent[] = {
+	{ "AU", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A1", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A2", "AUTHOR",       PERSON,  LEVEL_HOST },
+	{ "A3", "AUTHOR",       PERSON,  LEVEL_SERIES }, 
+	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
+	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
+	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
+	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T2", "SHORTTITLE",   SIMPLE,  LEVEL_HOST },
+	{ "T3", "TITLE",        SIMPLE,  LEVEL_SERIES },
+	{ "JO", "TITLE",        SIMPLE,  LEVEL_HOST }, /* JOURNAL */
+	{ "JA", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "JF", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J1", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J2", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "VL", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "VO", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "IS", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "CP", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "SP", "PAGESTART",    SIMPLE,  LEVEL_MAIN },
+	{ "EP", "PAGEEND",      SIMPLE,  LEVEL_MAIN },
+	{ "AB", "ABSTRACT",     SIMPLE,  LEVEL_MAIN },
+	{ "N1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "N2", "ABSTRACT",     SIMPLE,  LEVEL_MAIN }, 
+	{ "KW", "KEYWORD",      SIMPLE,  LEVEL_MAIN },
+	{ "PB", "PUBLISHER",    SIMPLE,  LEVEL_MAIN },
+	{ "BT", "TITLE",        SIMPLE,  LEVEL_HOST }, 
+	{ "CT", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "AD", "AUTHORADDRESS",SIMPLE,  LEVEL_MAIN },
+	{ "CY", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "RP", "REPRINTSTATUS",SIMPLE,  LEVEL_MAIN },
+	{ "UR", "URL",          SIMPLE,  LEVEL_MAIN },
+	{ "ID", "REFNUM",       SIMPLE,  LEVEL_MAIN },
+	{ "U1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*user defined */
+	{ "U2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "U3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U4", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U5", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*misc */
+	{ "M2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "M3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+        { "  ", "RESOURCE|text", ALWAYS, LEVEL_MAIN },
+        { "  ", "GENRE|patent", ALWAYS, LEVEL_MAIN }
+};
+
+static lookups electric[] = {
+	{ "AU", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A1", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A2", "AUTHOR",       PERSON,  LEVEL_HOST },
+	{ "A3", "AUTHOR",       PERSON,  LEVEL_SERIES }, 
+	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
+	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
+	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
+	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T2", "SHORTTITLE",   SIMPLE,  LEVEL_HOST },
+	{ "T3", "TITLE",        SIMPLE,  LEVEL_SERIES },
+	{ "JO", "TITLE",        SIMPLE,  LEVEL_HOST }, /* JOURNAL */
+	{ "JA", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "JF", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J1", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J2", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "VL", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "VO", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "IS", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "CP", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "SP", "PAGESTART",    SIMPLE,  LEVEL_MAIN },
+	{ "EP", "PAGEEND",      SIMPLE,  LEVEL_MAIN },
+	{ "AB", "ABSTRACT",     SIMPLE,  LEVEL_MAIN },
+	{ "N1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "N2", "ABSTRACT",     SIMPLE,  LEVEL_MAIN }, 
+	{ "KW", "KEYWORD",      SIMPLE,  LEVEL_MAIN },
+	{ "PB", "PUBLISHER",    SIMPLE,  LEVEL_MAIN },
+	{ "BT", "TITLE",        SIMPLE,  LEVEL_HOST }, 
+	{ "CT", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "AD", "AUTHORADDRESS",SIMPLE,  LEVEL_MAIN },
+	{ "CY", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "RP", "REPRINTSTATUS",SIMPLE,  LEVEL_MAIN },
+	{ "UR", "URL",          SIMPLE,  LEVEL_MAIN },
+	{ "ID", "REFNUM",       SIMPLE,  LEVEL_MAIN },
+	{ "U1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*user defined */
+	{ "U2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "U3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U4", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U5", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*misc */
+	{ "M2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "M3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+        { " ",  "RESOURCE|software, multimedia",    ALWAYS, LEVEL_MAIN },
+        { " ",  "GENRE|electronic",       ALWAYS, LEVEL_MAIN },
+};
+
+static lookups pamphlet[] = {
+	{ "AU", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A1", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A2", "AUTHOR",       PERSON,  LEVEL_HOST },
+	{ "A3", "AUTHOR",       PERSON,  LEVEL_SERIES }, 
+	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
+	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
+	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
+	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T2", "SHORTTITLE",   SIMPLE,  LEVEL_HOST },
+	{ "T3", "TITLE",        SIMPLE,  LEVEL_SERIES },
+	{ "JO", "TITLE",        SIMPLE,  LEVEL_HOST }, /* JOURNAL */
+	{ "JA", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "JF", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J1", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J2", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "VL", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "VO", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "IS", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "CP", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "SP", "PAGESTART",    SIMPLE,  LEVEL_MAIN },
+	{ "EP", "PAGEEND",      SIMPLE,  LEVEL_MAIN },
+	{ "AB", "ABSTRACT",     SIMPLE,  LEVEL_MAIN },
+	{ "N1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "N2", "ABSTRACT",     SIMPLE,  LEVEL_MAIN }, 
+	{ "KW", "KEYWORD",      SIMPLE,  LEVEL_MAIN },
+	{ "PB", "PUBLISHER",    SIMPLE,  LEVEL_MAIN },
+	{ "BT", "TITLE",        SIMPLE,  LEVEL_HOST }, 
+	{ "CT", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "AD", "AUTHORADDRESS",SIMPLE,  LEVEL_MAIN },
+	{ "CY", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "RP", "REPRINTSTATUS",SIMPLE,  LEVEL_MAIN },
+	{ "UR", "URL",          SIMPLE,  LEVEL_MAIN },
+	{ "ID", "REFNUM",       SIMPLE,  LEVEL_MAIN },
+	{ "U1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*user defined */
+	{ "U2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "U3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U4", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U5", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*misc */
+	{ "M2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "M3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+        { " ",  "RESOURCE|text",    ALWAYS, LEVEL_MAIN },
+        { " ",  "GENRE|pamphlet",       ALWAYS, LEVEL_MAIN },
+};
+
+static lookups unpublished[] = {
+	{ "AU", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A1", "AUTHOR",       PERSON,  LEVEL_MAIN },
+	{ "A2", "AUTHOR",       PERSON,  LEVEL_HOST },
+	{ "A3", "AUTHOR",       PERSON,  LEVEL_SERIES }, 
+	{ "ED", "EDITOR",       PERSON,  LEVEL_MAIN },
+	{ "PY", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y1", "YEAR",         DATE,    LEVEL_MAIN },
+	{ "Y2", "MONTH",     SIMPLE,  LEVEL_MAIN },
+	{ "SN", "SERIALNUMBER", SERIALNO,LEVEL_MAIN },
+	{ "TI", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T1", "TITLE",        TITLE,   LEVEL_MAIN },
+	{ "T2", "SHORTTITLE",   SIMPLE,  LEVEL_HOST },
+	{ "T3", "TITLE",        SIMPLE,  LEVEL_SERIES },
+	{ "JO", "TITLE",        SIMPLE,  LEVEL_HOST }, /* JOURNAL */
+	{ "JA", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "JF", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J1", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "J2", "TITLE",        SIMPLE,  LEVEL_HOST },
+	{ "VL", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "VO", "VOLUME",       SIMPLE,  LEVEL_MAIN },
+	{ "IS", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "CP", "ISSUE",        SIMPLE,  LEVEL_MAIN },
+	{ "SP", "PAGESTART",    SIMPLE,  LEVEL_MAIN },
+	{ "EP", "PAGEEND",      SIMPLE,  LEVEL_MAIN },
+	{ "AB", "ABSTRACT",     SIMPLE,  LEVEL_MAIN },
+	{ "N1", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "N2", "ABSTRACT",     SIMPLE,  LEVEL_MAIN }, 
+	{ "KW", "KEYWORD",      SIMPLE,  LEVEL_MAIN },
+	{ "PB", "PUBLISHER",    SIMPLE,  LEVEL_MAIN },
+	{ "BT", "TITLE",        SIMPLE,  LEVEL_HOST }, 
+	{ "CT", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "AD", "AUTHORADDRESS",SIMPLE,  LEVEL_MAIN },
+	{ "CY", "ADDRESS",      SIMPLE,  LEVEL_MAIN },
+	{ "RP", "REPRINTSTATUS",SIMPLE,  LEVEL_MAIN },
+	{ "UR", "URL",          SIMPLE,  LEVEL_MAIN },
+	{ "ID", "REFNUM",       SIMPLE,  LEVEL_MAIN },
+	{ "U1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*user defined */
+	{ "U2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "U3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U4", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "U5", "NOTES",        SIMPLE,  LEVEL_MAIN },
+	{ "M1", "NOTES",        SIMPLE,  LEVEL_MAIN }, /*misc */
+	{ "M2", "NOTES",        SIMPLE,  LEVEL_MAIN }, /* put in "notes" */
+	{ "M3", "NOTES",        SIMPLE,  LEVEL_MAIN },
+        { " ",         "RESOURCE|text",   ALWAYS, LEVEL_MAIN },
+        { " ",         "GENRE|unpublished",      ALWAYS, LEVEL_MAIN }
+};
 
 variants ris_all[] = {
 	{ "STD",  &(generic[0]), sizeof(generic)/sizeof(lookups)},
 	{ "GEN",  &(generic[0]), sizeof(generic)/sizeof(lookups)},
 	{ "JOUR", &(article[0]), sizeof(article)/sizeof(lookups)},
+	{ "MGZN", &(magarticle[0]), sizeof(magarticle)/sizeof(lookups)},
 	{ "BOOK", &(book[0]), sizeof(book)/sizeof(lookups)},
 	{ "CHAP", &(inbook[0]), sizeof(inbook)/sizeof(lookups)},
 	{ "CONF", &(conference[0]), sizeof(conference)/sizeof(lookups)},
@@ -619,10 +962,14 @@ variants ris_all[] = {
 	{ "NEWS", &(newsarticle[0]), sizeof(newsarticle)/sizeof(lookups)},
 	{ "MPCT", &(generic[0]), sizeof(generic)/sizeof(lookups)},
 	{ "PCOMM", &(communication[0]), sizeof(communication)/sizeof(lookups)},
-	{ "PAMP", &(generic[0]), sizeof(generic)/sizeof(lookups)},
-	{ "ELEC", &(generic[0]), sizeof(generic)/sizeof(lookups)},
+	{ "PAMP", &(pamphlet[0]), sizeof(pamphlet)/sizeof(lookups)},
+	{ "ELEC", &(electric[0]), sizeof(electric)/sizeof(lookups)},
 	{ "THES", &(thesis[0]), sizeof(thesis)/sizeof(lookups)},
-	{ "RPRT", &(report[0]), sizeof(report)/sizeof(lookups)}
+	{ "RPRT", &(report[0]), sizeof(report)/sizeof(lookups)},
+	{ "ABST", &(abstract[0]), sizeof(abstract)/sizeof(lookups)},
+	{ "COMP", &(program[0]), sizeof(program)/sizeof(lookups)},
+	{ "PAT",  &(patent[0]), sizeof(patent)/sizeof(lookups)},
+	{ "UNPB", &(unpublished[0]), sizeof(unpublished)/sizeof(lookups)},
 };
 
 int ris_nall = sizeof( ris_all ) / sizeof( variants );
