@@ -3,7 +3,7 @@
 #ifndef CROSSREFPLUGIN_H
 #define CROSSREFPLUGIN_H
 
-#include <libglademm.h>
+
 
 #include "Plugin.h"
 
@@ -14,6 +14,7 @@ class CrossRefPlugin : public Plugin
 	public:
 		CrossRefPlugin ();
 		~CrossRefPlugin () {};
+		virtual int canResolve (Document &doc);
 		virtual bool resolve (Document &doc);
 		virtual Glib::ustring const getShortName ();
 		virtual Glib::ustring const getLongName ();
@@ -25,7 +26,7 @@ class CrossRefPlugin : public Plugin
 	private:
 		bool ignoreChanges_;
 		void onPrefsChanged ();
-		Glib::RefPtr<Gnome::Glade::Xml> xml_;
+		Glib::RefPtr<Gtk::Builder> xml_;
 		Gtk::Dialog *dialog_;
 		Gtk::Entry  *usernameEntry_;
 		Gtk::Entry  *passwordEntry_;
