@@ -15,16 +15,18 @@
 
 #include <map>
 
-#include <libglademm.h>
 #include <gtkmm.h>
 
 #include "CaseFoldCompare.h"
+#include "DocumentTypes.h"
 
 class Document;
+class RefWindow;
 
 class DocumentProperties {
 	private:
-	Glib::RefPtr<Gnome::Glade::Xml> xml_;
+	Glib::RefPtr<Gtk::Builder> xml_;
+	RefWindow &win_;
 
 	/*
 	 * Local working copy
@@ -37,14 +39,19 @@ class DocumentProperties {
 
 	Gtk::Button *crossrefbutton_;
 	Gtk::Button *pastebibtexbutton_;
-	Gtk::Button *newextrafieldbutton_;
-	Gtk::Button *deleteextrafieldbutton_;
-	Gtk::Button *editextrafieldbutton_;
+	Gtk::ToolButton *newextrafieldbutton_;
+	Gtk::ToolButton *deleteextrafieldbutton_;
+	Gtk::ToolButton *editextrafieldbutton_;
 	Gtk::Expander *extrafieldsexpander_;
 	Gtk::TreeView *extrafieldsview_;
 	Glib::RefPtr<Gtk::TreeSelection> extrafieldssel_;
 
-	Gtk::ComboBoxEntryText *typeCombo_;
+	Gtk::ComboBox *typeCombo_;
+	Gtk::TreeModelColumn<Glib::ustring> typelabelcol_;
+	Gtk::TreeModelColumn<Glib::ustring> typebibtexnamecol_;
+	Gtk::TreeModel::ColumnRecord typecombocols_;
+	Glib::RefPtr< Gtk::ListStore > typecombostore_;
+	sigc::connection typecombochanged_;
 	typedef std::map <Glib::ustring, Gtk::Entry*, casefoldCompare> FieldEntryMap;
 	FieldEntryMap fieldEntries_;
 
@@ -70,10 +77,11 @@ class DocumentProperties {
 	void onFileChanged ();
 	void onIconButtonClicked ();
 	bool ignoreTypeChanged_;
+	DocumentTypeManager typeManager_;
 
 	public:
 		bool show (Document *doc);
-		DocumentProperties ();
+		DocumentProperties (RefWindow &refwin);
 };
 
 #endif
