@@ -23,7 +23,9 @@ class PluginCapability
 			PUBMED = 1 << 2,
 			DOCUMENT_ACTION = 1 << 3,
 			URL = 1 << 4,
-			SEARCH = 1 << 5
+			SEARCH = 1 << 5,
+			RESOLVE_METADATA = 1 << 6, /* generic metadata resolution capability */
+			/* XXX: In time DOI, ARXIV and PUBMED should go away, in place of RESOLVE_METADATA */
 		} Identifier;
 
 		void add (Identifier const id) {
@@ -74,6 +76,8 @@ class PluginCapability
 					return "Web URL";
 				case SEARCH:
 					return "Search";
+				case RESOLVE_METADATA:
+					return "Resolve metadata";
 				case NONE:
 				default:
 					return "Invalid PluginCapability for display";
@@ -95,6 +99,7 @@ class PluginCapability
 				case NONE:
 				case SEARCH:
 				case DOCUMENT_ACTION:
+				case RESOLVE_METADATA:
 				default:
 					return "";
 
@@ -111,11 +116,12 @@ class PluginCapability
 			retval.push_back (PUBMED);
 			retval.push_back (ARXIV);
 			retval.push_back (URL);
+			retval.push_back (RESOLVE_METADATA);
 			return retval;
 		}
 
 		bool hasMetadataCapability () {
-			return has (DOI) || has (ARXIV) || has (PUBMED) || has (URL);
+			return has (DOI) || has (ARXIV) || has (PUBMED) || has (URL) || has(RESOLVE_METADATA);
 		}
 };
 
@@ -134,7 +140,16 @@ class Plugin
 		virtual ~Plugin () {};
 
 		virtual void load (std::string const &moduleName) {};
+		
+		/* Lookup metadata, and add to document. Return true on success */
 		virtual bool resolve (Document &doc) = 0;
+		/* Return a priority for how well this plugin can handle this document.
+		 * Should not incur any network traffic.
+		 * Return: -1 if unable, or a positive integer if an attempt can be made.
+		 * 	(Suggested: integer from 1-100, depending on how well it might go.) */
+		virtual int canResolve (Document &doc) {
+			return 1;
+		};
 
 		virtual Glib::ustring const getShortName () = 0;
 		virtual Glib::ustring const getLongName () = 0;
@@ -168,6 +183,7 @@ class Plugin
 				enabled_ = false;
 		}
 
+		/* TODO mchro: eliminate PluginCapability, or make more generic */
 		PluginCapability cap_;
 
 		
